Documentation
¶
Index ¶
Constants ¶
const ( TypeSetAgentStatus = "AgentStatus" TypeUploadTestData = "TestData" )
Response type constants.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Base ¶
Base is a struct that is intended to be embedded by specific response structs. Both of these in conjunction are used primarily to house the JSON message for passing responses over the comms package (i.e. message queue), but may also contain important dependencies of the response, such as an HTTP handler.
type SetAgentStatus ¶
type SetAgentStatus struct {
Base
TestUUID string `json:"test_uuid"`
Status string `json:"status"`
}
SetAgentStatus defines this particular response.
func NewSetAgentStatus ¶
func NewSetAgentStatus(agentUUID, testUUID, status string) SetAgentStatus
NewSetAgentStatus returns a new SetAgentStatus response.
type UploadTestData ¶
type UploadTestData struct {
Base
TestUUID string `json:"test_uuid"`
TestData string `json:"test_data"`
}
UploadTestData defines this particular response.
func NewUploadTestData ¶
func NewUploadTestData(agentUUID, testUUID, testData string) UploadTestData
NewUploadTestData returns a new UploadTestData response.
Click to show internal directories.
Click to hide internal directories.